You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@kudu.apache.org by "Jean-Daniel Cryans (JIRA)" <ji...@apache.org> on 2017/07/21 21:42:00 UTC

[jira] [Created] (KUDU-2076) Deleting/updating is slow on single numeric row key tables

Jean-Daniel Cryans created KUDU-2076:
----------------------------------------

             Summary: Deleting/updating is slow on single numeric row key tables
                 Key: KUDU-2076
                 URL: https://issues.apache.org/jira/browse/KUDU-2076
             Project: Kudu
          Issue Type: Bug
          Components: tablet
    Affects Versions: 1.4.0
            Reporter: Jean-Daniel Cryans


A user reported that deleting 50M rows on the simplest of tables, (id INT, text STRING, PRIMARY KEY (id)), doesn't complete.

It reproduces locally and I was able to see that we're deleting 1.4 rows / ms which is awful considering that everything is cached.

Todd found that we're spending most of our time decoding big blocks of bit-shuffled keys. Intuitively he though that having a composite row key would perform better and indeed adding a column set to 0 in front makes it 10x faster.



--
This message was sent by Atlassian JIRA
(v6.4.14#64029)